﻿using System;
using System.Diagnostics.CodeAnalysis;
using System.Windows.Controls;

// Note: There should be 3 code analysis warnings.

// CA1804: Remove unused locals http://msdn.microsoft.com/en-us/library/ms182278.aspx
// CA1811: Avoid uncalled private code http://msdn.microsoft.com/en-us/library/ms182264.aspx
// CA1812: Avoid uninstantiated internal classes http://msdn.microsoft.com/en-us/library/ms182265.aspx
// CA1823: Avoid unused private fields http://msdn.microsoft.com/en-us/library/ms245042.aspx

namespace SilverlightApplication
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();
            DoNothing();
            using (var d = new Disposable())
            {
            }
            using (var e = new ExplicitDisposable())
            {
            }
        }

        private void UnusedPrivateMethod()
        {
            DoNothing();
        }

        public void UnusedPublicMethod()
        {
            DoNothing();
        }

        private void DoNothing()
        {
            Console.WriteLine(this);
        }
    }

    [SuppressMessage("Microsoft.Design", "CA1063:ImplementIDisposableCorrectly", Justification = "Simple implementation for test purposes.")]
    public class Disposable : IDisposable
    {
        public Disposable()
        {
            Console.WriteLine(this);
        }

        [SuppressMessage("Microsoft.Design", "CA1063:ImplementIDisposableCorrectly", Justification = "Simple implementation for test purposes.")]
        ~Disposable()
        {
            Console.WriteLine(this);
        }

        [SuppressMessage("Microsoft.Design", "CA1063:ImplementIDisposableCorrectly", Justification = "Simple implementation for test purposes.")]
        public void Dispose()
        {
            Console.WriteLine(this);
            GC.SuppressFinalize(this);
        }
    }

    [SuppressMessage("Microsoft.Design", "CA1063:ImplementIDisposableCorrectly", Justification = "Simple implementation for test purposes.")]
    public sealed class ExplicitDisposable : IDisposable
    {
        public ExplicitDisposable()
        {
            Console.WriteLine(this);
        }

        [SuppressMessage("Microsoft.Design", "CA1063:ImplementIDisposableCorrectly", Justification = "Simple implementation for test purposes.")]
        void IDisposable.Dispose()
        {
            Console.WriteLine(this);
            GC.SuppressFinalize(this);
        }
    }
}
